@@ -9,11 +9,11 @@ SeaBASS::File - Object-oriented interface for reading/writing SeaBASS files
 
 =head1 VERSION
 
-version 0.170190
+version 0.170480
 
 =cut
 
-our $VERSION = '0.170190'; # VERSION
+our $VERSION = '0.170480'; # VERSION
 
 =head1 SYNOPSIS
 
@@ -234,6 +234,7 @@ my %DEFAULT_OPTIONS = (
 	strict                 => STRICT_WRITE,
 	fill_ancillary_data    => 0,
 	preserve_header        => 0,
+	preserve_detection_limits => 0,
 );
 
 #return values for ref()
@@ -250,6 +251,7 @@ my %OPTION_TYPES = (
 	strict                 => [''],
 	fill_ancillary_data    => [''],
 	preserve_header        => [''],
+	preserve_detection_limits => [''],
 );
 
 # All headers required by STRICT_READ and STRICT_WRITE
@@ -323,11 +325,12 @@ our @ALL_HEADERS = qw(
 # headers that are allowed but are not to be added during add_empty_headers
 my @HIDDEN_HEADERS = qw(
 	received
-	optical_depth_warning
 );
 
 # what to set the missing value to if it's not defined
 our $DEFAULT_MISSING = -999;
+our $DEFAULT_BDL = -888;
+our $DEFAULT_ADL = -777;
 
 # overly complex data structure only understandable by idiots
 # your IQ is the percentage chance that it won't make sense
@@ -494,6 +497,13 @@ C<0> or C<1>, default C<0>.  Preserves header and comment order.  This option
 disables modifying the header, as well, but will not error if you try -- it will
 simply not be reflected in the output.
 
+=item * preserve_detection_limits
+
+C<0> or C<1>, default C<0>.  Disables setting values equal to below_detection_limit
+or above_detection_limit to null while reading files.  This should only be used
+during read-only operation, as there is no telling missing data from data
+outside limits.
+
 =back
 
 =cut
@@ -1529,8 +1539,8 @@ sub write {
 		}
 
 		my $missing = ( exists( $self->{'missing'} ) ? $self->{'missing'} : $DEFAULT_MISSING );
-		my $bdl     = ( exists( $self->{'below_detection_limit'} ) ? $self->{'below_detection_limit'} : $DEFAULT_MISSING );
-		my $adl     = ( exists( $self->{'above_detection_limit'} ) ? $self->{'above_detection_limit'} : $DEFAULT_MISSING );
+		my $bdl     = ( exists( $self->{'below_detection_limit'} ) ? $self->{'below_detection_limit'} : $DEFAULT_BDL );
+		my $adl     = ( exists( $self->{'above_detection_limit'} ) ? $self->{'above_detection_limit'} : $DEFAULT_ADL );
 
 		if ( $self->{'options'}{'preserve_header'} ) {
 			print join("\n", @{ $self->{'preserved_header'} }, '');
@@ -1550,10 +1560,10 @@ sub write {
 			my @headers_to_print;
 			
 			@headers_to_print = @ALL_HEADERS;
-			if ($missing eq $adl || $self->{'options'}{'missing_data_to_undef'}){
+			if ($missing eq $adl || ($self->{'options'}{'missing_data_to_undef'} && !$self->{'options'}{'preserve_detection_limits'})){
 				@headers_to_print = grep(!/above_detection_limit/i, @headers_to_print);
 			}
-			if ($missing eq $bdl || $self->{'options'}{'missing_data_to_undef'}){
+			if ($missing eq $bdl || ($self->{'options'}{'missing_data_to_undef'} && !$self->{'options'}{'preserve_detection_limits'})){
 				@headers_to_print = grep(!/below_detection_limit/i, @headers_to_print);
 			}
 			
@@ -1704,11 +1714,11 @@ sub make_data_hash {
 		if ( $self->{'options'}{'missing_data_to_undef'} ) {
 			if ( $self->{'missing_is_number'} && looks_like_number($v) && $v == $self->{'missing'} ) {
 				$ret{$k} = undef;
-			} elsif ( $self->{'adl_is_number'} && looks_like_number($v) && $v == $self->{'above_detection_limit'} ){
+			} elsif ( !$self->{'options'}{'preserve_detection_limits'} && $self->{'adl_is_number'} && looks_like_number($v) && $v == $self->{'above_detection_limit'} ){
 				$ret{$k} = undef;
-			} elsif ( $self->{'bdl_is_number'} && looks_like_number($v) && $v == $self->{'below_detection_limit'} ){
+			} elsif ( !$self->{'options'}{'preserve_detection_limits'} && $self->{'bdl_is_number'} && looks_like_number($v) && $v == $self->{'below_detection_limit'} ){
 				$ret{$k} = undef;
-            } elsif ($v eq $self->{'missing'} || $v eq $self->{'below_detection_limit'} || $v eq $self->{'above_detection_limit'}) {
+            } elsif ($v eq $self->{'missing'} || (!$self->{'options'}{'preserve_detection_limits'} && ($v eq $self->{'below_detection_limit'} || $v eq $self->{'above_detection_limit'}))) {
 				$ret{$k} = undef;
             } else {
 				$ret{$k} = $v;
@@ -1863,6 +1873,8 @@ sub create_blank_file {
 	$self->{'max_dataidx'}   = -1;
 	$self->{'delim'}         = undef;
 	$self->{'missing'}       = $DEFAULT_MISSING;
+	$self->{'below_detection_limit'} = $DEFAULT_BDL;
+	$self->{'above_detection_limit'} = $DEFAULT_ADL;
 
 	$self->{'options'}{'cache'}               = 1;
 	$self->{'options'}{'fill_ancillary_data'} = 0;
